@@ -1,10 +1,11 @@
+from __future__ import annotations
+
 from media_platform.lang.serialization import Serializable, Deserializable
 
 
 class Clipping(Serializable, Deserializable):
-    def __init__(self, start=None, duration=None, fade_in_duration=None, fade_out_duration=None, fade_in_offset=None,
-                 fade_out_offset=None):
-        # type: (int, int, int, int, int, int) -> None
+    def __init__(self, start: int = None, duration: int = None, fade_in_duration: int = None,
+                 fade_out_duration: int = None, fade_in_offset: int = None, fade_out_offset: int = None):
         self.start = start
         self.duration = duration
         self.fade_in_duration = fade_in_duration
@@ -13,13 +14,11 @@ class Clipping(Serializable, Deserializable):
         self.fade_out_offset = fade_out_offset
 
     @classmethod
-    def deserialize(cls, data):
-        # type: (dict) -> Clipping
+    def deserialize(cls, data: dict) -> Clipping:
         return cls(data.get('start'), data.get('duration'), data.get('fadeInDuration'), data.get('fadeOutDuration'),
                    data.get('fadeInOffset'), data.get('fadeOutOffset'))
 
-    def serialize(self):
-        # type: () -> dict
+    def serialize(self) -> dict:
         return {
             'start': self.start,
             'duration': self.duration,
